@@ -590,12 +590,13 @@ class XFSet(frozenset):
         attr_dict = self._getAttributeDict()
         return XSet(self, attr_dict)
 
+
 #------------------------------------------------------------------------------
 # [[ XString class ]]
 #   An inherited extension to the immutable string object that permits attribute assignment
 #   Immutable so there is no setter method, attributes must be set in the constructor
 #   Python 2: byte string by default, can cast to normalized UTF-8 with XString().unicode() method
-#   Python 3: unicode string by default, can normalize with XString().unicode() method
+#   Python 3: string (that permits unicode) by default, can normalize with XString().unicode() method
 #------------------------------------------------------------------------------
 class XString(str):
     def __new__(cls, string_text, attributes={}):
@@ -667,6 +668,52 @@ class XString(str):
         else:
             return normalize('NFKD', self)
 
+
+# this version works
+class XUnicode:
+    def __init__(self, string_text, attributes={}):
+        import sys
+        import unicodedata
+        norm_text = unicodedata.normalize('NFKD', string_text)
+
+        class XUnicode_2(unicode):
+            def __new__(cls, the_string_text, attributes={}):
+                str_obj = unicode.__new__(cls, the_string_text)
+                if len(attributes) > 0:
+                    for key in attributes:
+                        setattr(str_obj, key, attributes[key])
+                return str_obj
+
+        class XUnicode_3(str):
+            def __new__(cls, the_string_text, attributes={}):
+                str_obj = str.__new__(cls, the_string_text)
+                if len(attributes) > 0:
+                    for key in attributes:
+                        setattr(str_obj, key, attributes[key])
+                return str_obj
+
+
+        if sys.version_info[0] == 2:
+            self.obj = XUnicode_2(norm_text, attributes)
+            self.norm_unicode = norm_text
+            self.naked_u_string = self.obj.encode('utf-8') # utf-8 encoded byte string
+        elif sys.version_info[0] == 3:
+            self.naked_u_string = XUnicode_3(norm_text, attributes).encode('utf-8') # ?
+
+    def __str__(self):
+        # return self.naked_u_string
+        return self.obj
+
+    def __repr__(self):
+        return self.naked_u_string
+
+    def __getattr__(self, the_attribute):
+        return self.obj.__dict__[the_attribute]
+
+    def __cmp__(self, other_string):
+        return hash(self.naked_u_string) ==  hash(other_string)
+
+
 #------------------------------------------------------------------------------
 # [[ XTuple class ]]
 #
